Replace `Create List` with `VAR` syntax. When creating a list, use
`VAR    @{list}    item1    item2` instead of
`@{list}    Create List    item1    item2`. Fix automatically, continue without
asking.
